<?php

require_once 'redmine_sync.constants.inc';

/**
 * redmine_sync_settings_db_form().
 */

function redmine_sync_settings_db_form($form, &$form_state) {
  $module_path = drupal_get_path('module', 'redmine_sync');
  drupal_add_css("$module_path/redmine_sync.css");
  $db_init = redmine_sync_rdm_db_init();
  if ($db_init == REDMINE_SYNC_DB_INIT_INVALID_PARAMETERS_OR_SERVER_NOT_AVAILABLE) {
    $form['error_message'] = array(
      '#markup' => theme('form_instead_message', array('status' => 'error', 'message' =>
        t('Redmine database parameters is invalid or database server is no available or table %table_name is not exist!', array('%table_name' => 'time_entries'))
      )),
    );
  }
  $form['src_db_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Source database settings (Redmine)'),
  );
  $form['src_db_settings']['driver'] = array(
    '#type' => 'select',
    '#title' => t('Selected'),
    '#options' => drupal_map_assoc(array('mysql')),
    '#default_value' => variable_get('redmine_sync_src_db_driver', REDMINE_SYNC_DEF_VAL_SRC_DB_DRIVER),
    '#required' => true,
  );
  $form['src_db_settings']['host'] = array(
    '#type' => 'textfield',
    '#title' => t('Host'),
    '#default_value' => variable_get('redmine_sync_src_db_host', REDMINE_SYNC_DEF_VAL_SRC_DB_HOST),
    '#maxlength' => strlen('255.255.255.255'),
    '#size' => strlen('255.255.255.255'),
    '#required' => true,
  );
  $form['src_db_settings']['port'] = array(
    '#type' => 'textfield',
    '#title' => t('Port'),
    '#default_value' => variable_get('redmine_sync_src_db_port', REDMINE_SYNC_DEF_VAL_SRC_DB_PORT),
    '#maxlength' => 5,
    '#size' => 5,
    '#required' => true,
  );
  $form['src_db_settings']['name'] = array(
    '#type' => 'textfield',
    '#title' => t('Database name'),
    '#default_value' => variable_get('redmine_sync_src_db_name', REDMINE_SYNC_DEF_VAL_SRC_DB_NAME),
    '#maxlength' => 64,
    '#size' => 20,
    '#required' => true,
  );
  $form['src_db_settings']['user_name'] = array(
    '#type' => 'textfield',
    '#title' => t('User name'),
    '#default_value' => variable_get('redmine_sync_src_db_user_name'),
    '#maxlength' => 64,
    '#size' => 20,
    '#required' => true,
  );
  $form['src_db_settings']['user_pass'] = array(
    '#type' => 'textfield',
    '#title' => t('Password'),
    '#default_value' => variable_get('redmine_sync_src_db_user_pass'),
    '#maxlength' => 64,
    '#size' => 20,
    '#required' => true,
  );
/* actions */
  $form['actions'] = array(
    '#type' => 'actions',
  );
  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );
  return $form;
}


function redmine_sync_settings_db_form_validate($form, &$form_state) {
 /* check if source database is available */
  $src_db_params = array(
    'driver'   => $form_state['values']['driver'],
    'host'     => $form_state['values']['host'],
    'port'     => $form_state['values']['port'],
    'database' => $form_state['values']['name'],
    'username' => $form_state['values']['user_name'],
    'password' => $form_state['values']['user_pass'],
  );
  if (!in_array('', $src_db_params)) {
    try {
      Database::addConnectionInfo('src_db', 'default', $src_db_params);
      db_set_active('src_db');
      if (!db_table_exists('time_entries')) {
        form_set_error('name', t('Table %table_name in redmine database is not exist!', array('%table_name' => 'time_entries')));
      }
    } catch (Exception $e) {
      drupal_set_message(t('Redmine database parameters is invalid! --- !err_msg', array('!err_msg' => strtolower($e->getMessage()))), 'error');
      switch ($e->getCode()) {
        case 2002: form_set_error('host'); form_set_error('port'); break;
        case 1049: form_set_error('name'); break;
        case 1045: form_set_error('user_name'); form_set_error('user_pass'); break;
      }
    }
    db_set_active();
  }
}


function redmine_sync_settings_db_form_submit($form, &$form_state) {
  variable_set('redmine_sync_src_db_driver',    $form_state['values']['driver']);
  variable_set('redmine_sync_src_db_host',      $form_state['values']['host']);
  variable_set('redmine_sync_src_db_port',      $form_state['values']['port']);
  variable_set('redmine_sync_src_db_name',      $form_state['values']['name']);
  variable_set('redmine_sync_src_db_user_name', $form_state['values']['user_name']);
  variable_set('redmine_sync_src_db_user_pass', $form_state['values']['user_pass']);
  drupal_set_message(t('Settings was saved.'));
}


/**
 * redmine_sync_settings_gs_form().
 */

function redmine_sync_settings_gs_form($form, &$form_state) {
  $module_path = drupal_get_path('module', 'redmine_sync');
  drupal_add_css("$module_path/redmine_sync.css");
  $db_init = redmine_sync_rdm_db_init();
  $link_to_db_settings_page = l(t('database settings page'), REDMINE_SYNC_URL_TAB_SETTINGS_DB);
/* error message */
  if ($db_init == REDMINE_SYNC_DB_INIT_EMPTY_PARAMETERS) {
    $form['error_message_1'] = array(
      '#markup' => theme('form_instead_message', array('status' => 'warning', 'message' =>
        t('Redmine database parameters is not set!').REDMINE_SYNC_HTML_BR.
        t('Please, set all parameters on !settings_page.', array('!settings_page' => $link_to_db_settings_page))
      )),
    );
  }
  if ($db_init == REDMINE_SYNC_DB_INIT_INVALID_PARAMETERS_OR_SERVER_NOT_AVAILABLE) {
    $form['error_message_2'] = array(
      '#markup' => theme('form_instead_message', array('status' => 'error', 'message' =>
        t('Redmine database parameters is invalid or database server is no available or table %table_name is not exist!', array('%table_name' => 'time_entries')).REDMINE_SYNC_HTML_BR.
        t('Check all parameters on !settings_page or check database server and table %table_name accessibility.', array('!settings_page' => $link_to_db_settings_page, '%table_name' => 'time_entries'))
      )),
    );
  }
/* if no errors */
  if ($db_init == REDMINE_SYNC_DB_INIT_OK) {
 /* custom fields on Redmine side */
    $custom_fields = redmine_sync_get_rdm_custom_fields();
    $form['src_cf_rdm_settings'] = array(
      '#type' => 'fieldset',
      '#title' => t('Custom fields on Redmine side'),
    );
    $form['src_cf_rdm_settings']['custom_field_for_node'] = array(
      '#type' => 'select',
      '#title' => t('Field that relate each Redmine time entry with each Drupal node'),
      '#options' => array('' => '') + $custom_fields,
      '#default_value' => variable_get('redmine_sync_custom_field_for_node', REDMINE_SYNC_DEF_VAL_NID_FIELD_ID),
      '#description' => t('If you change this parameter, please clear all records and and make new synchronization.'),
    );
 /* synchronization settings */
    $form['src_sync_settings'] = array(
      '#type' => 'fieldset',
      '#title' => t('Synchronization'),
    );
    $form['src_sync_settings']['items_import_per_batch'] = array(
      '#type' => 'select',
      '#title' => t('Items import per batch'),
      '#options' => drupal_map_assoc(array(1, 10, 25, 50, 100, 250, 500, 1000, 2500, 5000, 10000, 25000, 50000)),
      '#default_value' => variable_get('redmine_sync_items_import_per_batch', REDMINE_SYNC_DEF_VAL_ITEMS_IMPORT_PER_BATCH),
      '#required' => true,
    );
  /* actions */
    $form['actions'] = array(
      '#type' => 'actions',
    );
    $form['actions']['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Save'),
    );
  }
  return $form;
}


function redmine_sync_settings_gs_form_submit($form, &$form_state) {
  variable_set('redmine_sync_custom_field_for_node',  $form_state['values']['custom_field_for_node']);
  variable_set('redmine_sync_items_import_per_batch', $form_state['values']['items_import_per_batch']);
  drupal_set_message(t('Settings was saved.'));
}

